class PySpy < Formula
  desc "Sampling profiler for Python programs"
  homepage "https://github.com/benfred/py-spy"
  license "MIT"
  head "https://github.com/benfred/py-spy.git", branch: "master"

  stable do
    url "https://github.com/benfred/py-spy/archive/refs/tags/v0.3.14.tar.gz"
    sha256 "c01da8b74be0daba79781cfc125ffcd3df3a0d090157fe0081c71da2f6057905"

    # Use `llvm@15` to work around build failure with LLVM Clang 16 (Apple Clang 15)
    # described in https://github.com/rust-lang/rust-bindgen/issues/2312.
    # TODO: Remove in the next release
    depends_on "llvm@15" => :build if DevelopmentTools.clang_build_version >= 1500
  end

  depends_on "rust" => :build
  depends_on "python@3.12" => :test

  on_linux do
    depends_on "libunwind"
  end

  def install
    odie "Check if `llvm@15` dependency can be removed!" if build.stable? && version > "0.3.14"
    ENV.remove "HOMEBREW_LIBRARY_PATHS", Formula["llvm@15"].opt_lib

    system "cargo", "install", *std_cargo_args

    generate_completions_from_executable(bin/"py-spy", "completions")
  end

  test do
    python = Formula["python@3.12"].opt_bin/"python3.12"
    output = shell_output("#{bin}/py-spy record #{python} 2>&1", 1)
    assert_match "Try running again with elevated permissions by going", output
  end
end
